@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # -----------------------------------------------------------------------------
-# Gettings Things Gnome! - a personal organizer for the GNOME desktop
-# Copyright (c) 2008-2009 - Lionel Dricot & Bertrand Rousseau
+# Getting Things GNOME! - a personal organizer for the GNOME desktop
+# Copyright (c) 2008-2013 - Lionel Dricot & Bertrand Rousseau
 #
 # This program is free software: you can redistribute it and/or modify it under
 # the terms of the GNU General Public License as published by the Free Software
@@ -17,20 +17,14 @@
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 # -----------------------------------------------------------------------------
 
-"""
-This is the UI manager. It loads the prefs and manages every window and UI in GTG.
+""" Configuration for browser, it contains path to .glade files """
 
-There should be no horizontal communication at all between views.
-"""
 import os
 
-from GTG     import _
-
 
 class ViewConfig:
-
-
     current_rep = os.path.dirname(os.path.abspath(__file__))
-    DELETE_GLADE_FILE  = os.path.join(current_rep, "deletion.glade")
+    DELETE_GLADE_FILE = os.path.join(current_rep, "deletion.glade")
     PREFERENCES_GLADE_FILE = os.path.join(current_rep, "preferences.glade")
+    PLUGINS_GLADE_FILE = os.path.join(current_rep, "plugins.glade")
     BACKENDS_GLADE_FILE = os.path.join(current_rep, "backends_dialog.glade")
