@@ -14,12 +14,9 @@
 # You should have received a copy of the GNU General Public License along with
 # this program.  If not, see <http://www.gnu.org/licenses/>.
 
-import sys
-import os
-sys.path.insert(0, os.getcwd())
-
-from tomboy import pluginTomboy
+from GTG.plugins.tomboy.tomboy import pluginTomboy
 
 
-#suppress pyflakes warning (given by make lint)
-if False == True: pluginTomboy()
+# suppress pyflakes warning (given by make lint)
+if False is True:
+    pluginTomboy()
